@@ -61,7 +61,17 @@ void CLTreef::addSeq(int *bid, int n, myFlt w)
 {
 	if (n==1)
 	{
-		if (this->daughter[*bid].f==0){
+		//check the given bid has already been added.  debugged by Dongwon Lee 1/11/15
+		int found = 0;
+		for (int i=0;i<this->nonEmptyDaughterCnt;i++) 
+		{
+			if (this->nonEmptyDaughterIdxs[i] == *bid) 
+			{
+				found = 1;
+				break;
+			}
+		}
+		if (found == 0){
 			this->nonEmptyDaughterIdxs[this->nonEmptyDaughterCnt++]=*bid;
 		}
 		this->daughter[*bid].f +=w; 
